/*

littleBits DIY Smart Thermostat
cloudBit Example Project created 7/22/14
for more projects and resources, visit littleBits.cc

CODE FOR TEMPERATURE INPUT ARDUINO

*/



//INPUTS:
int cloudInputPin = A1;           // Set the pin for reading input from the cloudBit
int dimmerInputPin = A0;          // Set the pin for reading input from the dimmer module

//OUTPUTS:

int targetTempPin = 5;            // Set the pin for sending the desired temperature to the Temperature Control Arduino

//VARIABLES:

unsigned int cloudSample = 0;    // For readings taken from the cloudBit
unsigned int cloudValue = 0;     // Stores results from calculation for filtering data from cloudBit
int cloudFiltered = 0;           // Stores results of filtered data
int cloudPreviousValue = 0;      // Stores input from previous loop

int dimmerValue = 0;              // For readings taken from the dimmer input
int dimmerPreviousValue = 0;      // Stores input from previous loop

int targetTemp = 0;               // Desired temperature
int targetTempPWM = 0;            // Desired temperature converted to PWM to send to Temperature Control Arduino



void setup()
{
  pinMode(cloudInputPin, INPUT);
  pinMode(dimmerInputPin, INPUT);
  pinMode(targetTempPin, OUTPUT);
 
  targetTemp = analogRead(dimmerInputPin);            // On startup, target temp is determined by the dimmer (cloud will not be inputing data until it has connected with wifi
  targetTempPWM = map(targetTemp, 0, 1023, 0, 255);   // Convert target temp to PWM 
  analogWrite(targetTempPin, targetTempPWM);          // Send converted temp to Temp Control Arduino
  
  cloudSample = analogRead(cloudInputPin);            // Read the input from the cloud module
  cloudValue = cloudSample * 50;                      // Setup cloudValue for use with the filtering equation
  
  Serial.begin(9600);                                 // Begin serial monitor for debugging
}

void loop()
{
  
  cloudValue = cloudValue - (cloudValue/50) + cloudSample;   // Equation for smoothing data from cloudBit
  cloudFiltered = cloudValue/50;                             // Equation for smoothing data from cloudBit
  cloudSample = analogRead(cloudInputPin);                   // Equation for smoothing data from cloudBit
  
  dimmerValue = analogRead(dimmerInputPin);                  // Read signal fromt the dimmer


  
  if (cloudFiltered > cloudPreviousValue + 10 || cloudFiltered < cloudPreviousValue - 10) // If the reading from the cloudBit has changed since the last loop (+- 10 for more data smoothing), then:
  {
    cloudPreviousValue = cloudFiltered;                      // Log this value as the previous value for the next loop        
    targetTemp = cloudFiltered;                              // Set the target temp to the value coming from the cloudBit
    targetTempPWM = map(targetTemp, 0, 1023, 0, 255);        // Convert the target temp to a PWM Value
    analogWrite(targetTempPin, targetTempPWM);               // Send this PWM value to the Temp Control Arduino
    
    /*
    Serial.print("Cloud Sample: ");
    Serial.println(cloudSample);
    Serial.print("Cloud Filtered Value: ");
    Serial.println(cloudFiltered);
    Serial.print("Previous Cloud Value: ");
    Serial.println(cloudPreviousValue);
    Serial.println("CLOUD changed");
    Serial.println("----------");
    */
    delay(500);
    
  }
  else if (dimmerValue > dimmerPreviousValue + 10 || dimmerValue < dimmerPreviousValue - 10) // If the reading from the dimmer has changed since the last loop (+- 10 for more data smoothing), then:
  {
    dimmerPreviousValue = dimmerValue;                    // Log this value as the previous value for the next loop
    targetTemp = dimmerValue;                             // Set the target temp to the value coming from the cloudBit
    targetTempPWM = map(targetTemp, 0, 1023, 0, 255);     // Convert the target temp to a PWM Value
    analogWrite(targetTempPin, targetTempPWM);            // Send this PWM value to the Temp Control Arduino
    
    /*
    Serial.print("Previous Dimmer Value: ");
    Serial.println(dimmerPreviousValue);
    Serial.print("Dimmer Current Value: ");
    Serial.println(dimmerValue);
    Serial.println("DIMMER changed");
    Serial.println("----------");
    */
    delay(100);
  }
  
  else
  {
    delay(100);
  }

}
  
